Module align

Module align 

Typestate markers for statically and dynamically guaranteed slice alignment.

Provides types that represent memory alignment bounds at the type level, allowing SIMD operations to dispatch to faster aligned loading instructions (load_aligned) instead of unaligned loading instructions safely.

Structs

Aligned
A static alignment guarantee of A bytes.
Unaligned
No static alignment guarantee.

Traits

Alignment
Trait representing a memory alignment guarantee.

Functions

is_aligned_for_arch
Helper to check if the alignment Align is sufficient for architecture Arch vector register width.