Module view

Module view 

Safely typed views over slices with static alignment, architecture dispatch, reference typestates, and execution mode.

Re-exports

pub use tile::TileMatrixMultiply;
pub use tile::TileView;
pub use mask_reg::Mask;
pub use vector_reg::Vector;

Modules

gather
Vectorized indirect load (gather) operations.
mask_reg
Module containing the SIMD mask register wrappers. Monomorphized SIMD mask register wrapper.
masked
Lane-masked math and compaction/expansion operations on SIMD views.
ops
Standard elementwise and accumulation operations on SIMD views. Elementwise and transform operations over SimdView.
ops_mut
Standard exclusive mutable elementwise operations on SIMD views. Mutable elementwise SIMD operations on views backed by &'a mut [T].
reduce
Unrolled generic horizontal reductions on SIMD views. Horizontal and pairwise SIMD reductions over SimdView.
scan
Inclusive/exclusive prefix scans and running min/max.
select
Lane-wise conditional select and masked-negate. Conditional SIMD blend/select operations on SimdView.
tile
2D matrix tile views and operations. 2D matrix tile views for high-performance tiled and register-blocked matrix multiply kernels.
unary
Unary mapping operations on SIMD views.
vector_ops
Module containing operator overload implementations for SIMD vectors. Operator overloads for SIMD vectors. Operator overload implementations for the Vector register wrapper.
vector_reg
Module containing the generic SIMD vector register wrappers. Monomorphized SIMD vector register wrapper.

Structs

SimdView
A zero-copy, typed slice view parameterized by architecture, alignment, execution mode, and reference typestates.

Enums

SimdError
Error types for SIMD view operations.