Mask

Struct Mask 

#[repr(transparent)]
pub struct Mask<T, Arch>
where Arch: SimdArch + SimdKernel<T>, T: Scalar,
{ pub raw: Arch::Mask, /* private fields */ }
A type-safe, architecture-native SIMD mask type.

Fields

raw: Arch::Mask

The underlying raw mask register or representation.

Implementations

Source

impl<T, Arch> Mask<T, Arch>
where Arch: SimdArch + SimdKernel<T>, T: Scalar,

pub const fn new(raw: Arch::Mask) -> Self

Create a new Mask wrapping a raw mask register.

pub unsafe fn from_bitmask(bm: BitMask<64>) -> Self

Construct a Mask from a portable BitMask<64>.

Safety

Processor must support the target feature of Arch.

pub unsafe fn to_bitmask(self) -> BitMask<64>

Convert the Mask to a portable BitMask<64>.

Safety

Processor must support the target feature of Arch.

pub fn any(self) -> bool

Returns true if any lanes of the mask are active.

pub fn all(self) -> bool

Returns true if all lanes of the mask are active.

pub fn none(self) -> bool

Returns true if no lanes of the mask are active.

pub fn select( self, true_val: Vector<T, Arch>, false_val: Vector<T, Arch>, ) -> Vector<T, Arch>

Select elements from true_val where the mask is active, and from false_val otherwise.