pub struct TileView<'a, T: NumericElement, Backend, Arch, const ROWS: usize, const COLS: usize, Align: Alignment = Unaligned, Ref: 'a = &'a [T]> { /* private fields */ }Expand description
A 2D matrix tile view, parameterized by dimensions, alignment, execution mode, and backing reference type.
Under the hood, this represents a 2D tile of shape ROWS x COLS with a specified row stride.
It is represented as #[repr(C)] to guarantee layout compatibility.
Implementations
Sourceimpl<'a, T: NumericElement, Backend, Arch: SimdArch, const ROWS: usize, const COLS: usize, Align: Alignment> TileView<'a, T, Backend, Arch, ROWS, COLS, Align, &'a [T]>
impl<'a, T: NumericElement, Backend, Arch: SimdArch, const ROWS: usize, const COLS: usize, Align: Alignment> TileView<'a, T, Backend, Arch, ROWS, COLS, Align, &'a [T]>
Sourceimpl<'a, T: NumericElement, Backend, Arch: SimdArch, const ROWS: usize, const COLS: usize, Align: Alignment> TileView<'a, T, Backend, Arch, ROWS, COLS, Align, &'a mut [T]>
impl<'a, T: NumericElement, Backend, Arch: SimdArch, const ROWS: usize, const COLS: usize, Align: Alignment> TileView<'a, T, Backend, Arch, ROWS, COLS, Align, &'a mut [T]>
Sourcepub fn new_mut(data: &'a mut [T], stride: usize) -> Option<Self>
pub fn new_mut(data: &'a mut [T], stride: usize) -> Option<Self>
Create a new mutable TileView after verifying bounds and alignment invariants.
Returns None if the input slice is too small or if alignment constraints are not met.
Sourcepub fn as_mut_ptr(&mut self) -> *mut T
pub fn as_mut_ptr(&mut self) -> *mut T
Access the underlying raw mutable pointer.