Typestate markers for statically and dynamically guaranteed slice alignment.
Provides types that represent memory alignment bounds at the type level, allowing
SIMD operations to dispatch to faster aligned loading instructions (load_aligned)
instead of unaligned loading instructions safely.
Structs
Traits
- Alignment
- Trait representing a memory alignment guarantee.
Functions
- is_
aligned_ for_ arch - Helper to check if the alignment
Alignis sufficient for architectureArchvector register width.